@@ -6,9 +6,9 @@
 #' concentration with a mechanistic description of the effects on survival over
 #' time.
 #' 
-#' The function \code{survFit} return the parameter estimates of Toxicokinetic-toxicodynamic (TK-TD) models
+#' The function \code{survFit} return the parameter estimates of Toxicokinetic-toxicodynamic (TKTD) models
 #' \code{SD} for 'Stochastic Death' or \code{IT} fo 'Individual Tolerance'.
-#' TK-TD models, and particularly the General Unified Threshold model of
+#' TKTD models, and particularly the General Unified Threshold model of
 #' Survival (GUTS), provide a consistent process-based
 #' framework to analyse both time and concentration dependent datasets.
 #' In GUTS-SD, all organisms are assumed to have the same internal concentration 
@@ -54,7 +54,7 @@
 #' for the MCMC computation}
 #' \item{mcmcInfo}{a table with the number of iterations, chains, adaptation, warmup and the thinning interval.} 
 #' \item{jags.data}{a list of the data passed to the JAGS model}
-#' \item{model_type}{the type of TK-TD model used: \code{SD} or \code{IT}}
+#' \item{model_type}{the type of TKTD model used: \code{SD} or \code{IT}}
 #'
 #' @references Jager, T., Albert, C., Preuss, T. G. and Ashauer, R. (2011) 
 #' General unified threshold model of survival-a toxicokinetic-toxicodynamic
@@ -72,7 +72,7 @@
 #' dataset  <- survData(propiconazole)
 #'
 #' \dontrun{
-#' # (3) Run the survFit function with TK-TD model 'SD' or 'IT' 
+#' # (3) Run the survFit function with TKTD model 'SD' or 'IT' 
 #' out <- survFit(dataset , model_type = "SD")
 #'
 #' # (4) Summarize look the estimated parameters
@@ -85,11 +85,12 @@
 #' plot(out, spaghetti = TRUE , adddata = TRUE)
 #' }
 #'
-#' @export
 #' @import rjags
 #' @importFrom stats update
 #' @importFrom dplyr group_by summarise filter
 #'
+#' @export
+#'
 survFit.survDataCstExp <- function(data,
                                    model_type = NULL,
                                    quiet = FALSE,
@@ -112,11 +113,15 @@ survFit.survDataCstExp <- function(data,
   if(is.null(model_type) || ! (model_type %in% c("SD","IT"))) {
     stop("You need to specify a 'model_type' among 'SD' or 'IT'")
   }
-
   ### check number of sample for the diagnostic procedure
   if (n.chains < 2) {
     stop('2 or more parallel chains required')
   }
+  ### warning message when hb_value = NULL
+  if(hb_value==FALSE){
+    warning("This is not an error message: the parameter 'hb' is fixed to 0. This means that the correlation between
+            'hb' and other parameters is ignored.")
+  }
 
   ##
   ## Data and Priors for model
